@@ -23,10 +23,9 @@
 #include <glib/gi18n.h>
 
 #include "seahorse-application.h"
-#include "seahorse-icons.h"
+#include "seahorse-common.h"
 #include "seahorse-keyserver-control.h"
 #include "seahorse-prefs.h"
-#include "seahorse-registry.h"
 #include "seahorse-servers.h"
 #include "seahorse-util.h"
 #include "seahorse-widget.h"
@@ -234,7 +233,7 @@ calculate_keyserver_uri (SeahorseWidget *swidget)
     gchar **types;
     gint active;
     gchar *uri;
-    guint i;
+    gint i;
 
     /* Figure out the scheme */
     widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "keyserver-type"));
