@@ -31,9 +31,8 @@
 #include "seahorse-pgp-actions.h"
 #include "seahorse-pgp-key.h"
 
-#include "seahorse-place.h"
+#include "seahorse-common.h"
 #include "seahorse-progress.h"
-#include "seahorse-registry.h"
 #include "seahorse-util.h"
 #include "seahorse-passphrase.h"
 
@@ -623,7 +622,7 @@ on_keyring_import_complete (gpgme_error_t gerr,
 	gpgme_import_status_t import;
 	GError *error = NULL;
 	const gchar *msg;
-	guint i;
+	gint i;
 
 	if (seahorse_gpgme_propagate_error (gerr, &error)) {
 		g_simple_async_result_take_error (res, error);
@@ -802,29 +801,62 @@ seahorse_gpgme_keyring_init (SeahorseGpgmeKeyring *self)
 	}
 }
 
+static gchar *
+seahorse_gpgme_keyring_get_label (SeahorsePlace *place)
+{
+	return g_strdup (_("GnuPG keys"));
+}
+
+static gchar *
+seahorse_gpgme_keyring_get_description (SeahorsePlace *place)
+{
+	return g_strdup (_("GnuPG: default keyring directory"));
+}
+
+static GIcon *
+seahorse_gpgme_keyring_get_icon (SeahorsePlace *place)
+{
+	return g_themed_icon_new (GCR_ICON_GNUPG);
+}
+
+static GtkActionGroup *
+seahorse_gpgme_keyring_get_actions (SeahorsePlace *place)
+{
+	SeahorseGpgmeKeyring *self = SEAHORSE_GPGME_KEYRING (place);
+	if (self->pv->actions)
+		return g_object_ref (self->pv->actions);
+	return NULL;
+}
+
+static gchar *
+seahorse_gpgme_keyring_get_uri (SeahorsePlace *place)
+{
+	return g_strdup ("gnupg://");
+}
+
 static void
 seahorse_gpgme_keyring_get_property (GObject *obj,
                                      guint prop_id,
                                      GValue *value,
                                      GParamSpec *pspec)
 {
-	SeahorseGpgmeKeyring *self = SEAHORSE_GPGME_KEYRING (obj);
+	SeahorsePlace *place = SEAHORSE_PLACE (obj);
 
 	switch (prop_id) {
 	case PROP_LABEL:
-		g_value_set_string (value, _("GnuPG keys"));
+		g_value_take_string (value, seahorse_gpgme_keyring_get_label (place));
 		break;
 	case PROP_DESCRIPTION:
-		g_value_set_string (value, _("GnuPG: default keyring directory"));
+		g_value_take_string (value, seahorse_gpgme_keyring_get_description (place));
 		break;
 	case PROP_ICON:
-		g_value_take_object (value, g_themed_icon_new (GCR_ICON_GNUPG));
+		g_value_take_object (value, seahorse_gpgme_keyring_get_icon (place));
 		break;
 	case PROP_URI:
-		g_value_set_string (value, "gnupg://");
+		g_value_take_string (value, seahorse_gpgme_keyring_get_uri (place));
 		break;
 	case PROP_ACTIONS:
-		g_value_set_object (value, self->pv->actions);
+		g_value_take_object (value, seahorse_gpgme_keyring_get_actions (place));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
@@ -900,8 +932,13 @@ seahorse_gpgme_keyring_class_init (SeahorseGpgmeKeyringClass *klass)
 static void
 seahorse_gpgme_keyring_place_iface (SeahorsePlaceIface *iface)
 {
-	iface->load_async = seahorse_gpgme_keyring_load_async;
+	iface->load = seahorse_gpgme_keyring_load_async;
 	iface->load_finish = seahorse_gpgme_keyring_load_finish;
+	iface->get_actions = seahorse_gpgme_keyring_get_actions;
+	iface->get_description = seahorse_gpgme_keyring_get_description;
+	iface->get_icon = seahorse_gpgme_keyring_get_icon;
+	iface->get_label = seahorse_gpgme_keyring_get_label;
+	iface->get_uri = seahorse_gpgme_keyring_get_uri;
 }
 
 static guint
@@ -976,5 +1013,7 @@ seahorse_gpgme_keyring_new_context (gpgme_error_t *gerr)
 
 	gpgme_set_passphrase_cb (ctx, (gpgme_passphrase_cb_t)passphrase_get, NULL);
 	gpgme_set_keylist_mode (ctx, GPGME_KEYLIST_MODE_LOCAL);
+	if (gerr)
+		*gerr = 0;
 	return ctx;
 }
