@@ -32,8 +32,6 @@
 
 #include "seahorse-bind.h"
 #include "seahorse-common.h"
-#include "seahorse-delete-dialog.h"
-#include "seahorse-icons.h"
 #include "seahorse-object.h"
 #include "seahorse-object-model.h"
 #include "seahorse-object-widget.h"
@@ -261,7 +259,7 @@ on_pgp_signature_row_activated (GtkTreeView *treeview,
 static void
 unique_strings (GPtrArray *keyids)
 {
-	gint i;
+	guint i;
 
 	g_ptr_array_sort (keyids, (GCompareFunc)g_ascii_strcasecmp);
 	for (i = 0; i + 1 < keyids->len; ) {
@@ -1530,7 +1528,7 @@ on_pgp_trust_marginal_toggled (GtkToggleButton *toggle,
 {
     SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
     GObject *object;
-    guint trust;
+    SeahorseValidity trust;
     gpgme_error_t err;
 
     object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
@@ -1961,7 +1959,7 @@ setup_private_properties (SeahorsePgpKey *pkey, GtkWindow *parent)
     return swidget;
 }
 
-void
+GtkWindow *
 seahorse_pgp_key_properties_show (SeahorsePgpKey *pkey, GtkWindow *parent)
 {
 	SeahorseWidget *swidget;
@@ -1976,6 +1974,10 @@ seahorse_pgp_key_properties_show (SeahorsePgpKey *pkey, GtkWindow *parent)
 		swidget = setup_public_properties (pkey, parent);
 	else
 		swidget = setup_private_properties (pkey, parent);
-	if (swidget)
+	if (swidget) {
 		seahorse_widget_show (swidget);
+		return g_object_ref (seahorse_widget_get_toplevel (swidget));
+	}
+
+	return NULL;
 }
