@@ -32,10 +32,8 @@
 #include "seahorse-ssh-key.h"
 #include "seahorse-ssh-operation.h"
 
-#include "seahorse-action.h"
-#include "seahorse-icons.h"
+#include "seahorse-common.h"
 #include "seahorse-progress.h"
-#include "seahorse-registry.h"
 #include "seahorse-util.h"
 #include "seahorse-widget.h"
 
@@ -67,7 +65,7 @@ seahorse_ssh_generate_register (void)
 	gtk_action_group_add_actions (actions, ACTION_ENTRIES, G_N_ELEMENTS (ACTION_ENTRIES), NULL);
 	
 	/* Register this as a generator */
-	seahorse_registry_register_object (NULL, G_OBJECT (actions), SEAHORSE_SSH_TYPE_STR, "generator", NULL);
+	seahorse_registry_register_object (G_OBJECT (actions), "generator");
 }
 
 /* --------------------------------------------------------------------
@@ -133,7 +131,7 @@ on_generate_complete_and_upload (GObject *source,
 }
 
 static void
-on_response (GtkDialog *dialog, guint response, SeahorseWidget *swidget)
+on_response (GtkDialog *dialog, gint response, SeahorseWidget *swidget)
 {
     SeahorseSSHSource *src;
     GCancellable *cancellable;
